pub struct RoomMemberWithSenderInfo {
pub room_member: RoomMember,
pub sender_info: Option<RoomMember>,
}Expand description
Contains the current user’s room member info and the optional room member
info of the sender of the m.room.member event that this info represents.
Fields
room_member: RoomMemberThe actual room member.
sender_info: Option<RoomMember>The info of the sender of the event room_member is based on, if
available.